# edmar_py1


[![image](https://img.shields.io/pypi/v/edmar_py1.svg)](https://pypi.python.org/pypi/edmar_py1)
[![image](https://img.shields.io/conda/vn/conda-forge/edmar_py1.svg)](https://anaconda.org/conda-forge/edmar_py1)


**Python package for interactive mapping.**


-   Free software: MIT license
-   Documentation: https://geofixit.github.io/edmar_py1
    

## Features

-   TODO
